Ce site est un projet collaboratif d'annales des examens du brevet des collèges et du baccalauréat. Ce n'est pas un site officiel de l'éducation nationale.

## Contribuer

Le développement du projet a lieu ici sur GitLab (similaire à GitHub). Vous pouvez créer un compte GitLab (gratuit) pour pouvoir contribuer à la copie des sujets et la rédaction des corrections, ou pour contribuer à la partie technique (programmation Python et développement web). En revanche vous pouvez parcourir le contenu du projet sans avoir de compte GitLab.

Le guide de contribution se trouve ici: https://gitlab.com/cedricvanrompay/annales-brevet-et-bac/blob/master/CONTRIBUTING.md

Le projet est sous license MIT (plus d'info sur https://opensource.org), et toutes les contributions sont implicitement sous cette license. Cela garantit que le contenu puisse être copié/utilisé/modifié/amélioré par d'autres personnes et possiblement dans d'autres projets.

Vous pouvez aussi faire un don au mainteneur (Cédric VAN ROMPAY) pour soutenir le développement de la plateforme et la gestion des contributions: